"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var DateFormat;
(function (DateFormat) {
    DateFormat["forwardSlashMMDDYYYY"] = "MM/DD/YYYY";
    DateFormat["dashMMDDYYYY"] = "MM-DD-YYYY";
    DateFormat["forwardSlashDDMMYYYY"] = "DD/MM/YYYY";
})(DateFormat = exports.DateFormat || (exports.DateFormat = {}));
var Dates = /** @class */ (function () {
    function Dates() {
        this.date = new Date();
        this.day = this.date.getDate();
        this.month = this.date.getMonth() + 1;
        this.year = this.date.getFullYear();
    }
    /**
     * Set the format of your dates
     */
    Dates.prototype.setFormat = function (dateFormat) {
        switch (dateFormat) {
            case "MM/DD/YYYY":
                this.dateSymbol = { symbol: '/', position: "Day second" };
                break;
            case "MM-DD-YYYY":
                this.dateSymbol = { symbol: '-', position: "" };
                break;
            case "DD/MM/YYYY":
                this.dateSymbol = { symbol: '/', position: "Day first" };
                break;
            default:
                throw new Error("Invalid date format");
        }
        this.dateFormat = dateFormat;
    };
    /**
     * get the format
     */
    Dates.prototype.getFormat = function () {
        return this.dateFormat;
    };
    /**
     * get the today's date
     */
    Dates.prototype.today = function () {
        var dateResult = { first: this.day };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the yesterday's date
     */
    Dates.prototype.yesterday = function () {
        var day = this.day - 1;
        var dateResult = { first: day };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the current week first and last date
     */
    Dates.prototype.currentWeek = function () {
        var first;
        var last;
        first = this.day - this.date.getDay();
        last = first + 6;
        var daysinMonth = new Date(this.year, this.month, 0).getDate();
        if (last > daysinMonth) {
            last = last - daysinMonth;
            last = { date: last, month: this.date.getMonth() + 2 };
            var dateResult = { first: first, last: last };
        }
        else {
            var dateResult = { first: first, last: last };
        }
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the current month first and last date
     */
    Dates.prototype.currentMonth = function () {
        var last = new Date(this.year, this.month, 0).getDate();
        var dateResult = { first: '1', last: last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the next month first and last date
     */
    Dates.prototype.nextMonth = function () {
        var first;
        var last;
        var nextMonth = this.date.getMonth() + 2;
        var year = this.date.getFullYear();
        last = new Date(year, nextMonth, 0).getDate();
        if (nextMonth == 12) {
            year = this.date.getFullYear() + 1;
            last = new Date(year, nextMonth, 0).getDate();
        }
        first = { date: '1', month: nextMonth, year: year };
        last = { date: last, month: nextMonth, year: year };
        var dateResult = { first: first, last: last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the next week first and last date
     */
    Dates.prototype.nextWeek = function () {
        var first;
        var last;
        first = this.day - this.date.getDay() + 7;
        last = first + 6;
        var daysinMonth = new Date(this.year, this.month, 0).getDate();
        if (first > daysinMonth && last > daysinMonth) {
            first = first - daysinMonth;
            last = last - daysinMonth;
            first = { date: first, month: this.date.getMonth() + 2 };
            last = { date: last, month: this.date.getMonth() + 2 };
            var dateResult = { first: first, last: last };
        }
        else if (last > daysinMonth) {
            last = last - daysinMonth;
            last = { date: last, month: this.date.getMonth() + 2 };
            var dateResult = { first: first, last: last };
        }
        else {
            var dateResult = { first: first, last: last };
        }
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the last week first and last date
     */
    Dates.prototype.lastWeek = function () {
        var first;
        var last;
        var lastMonth;
        var dateResult;
        if (this.day <= 7) {
            lastMonth = this.date.getMonth();
            var daysinMonth = new Date(this.year, this.month, 0).getDate();
            var lastDay = this.day - this.date.getDay();
            var daysPassed = daysinMonth - lastDay + 1;
            var daysLeft = daysinMonth - daysPassed;
            var numOfDaysInWeek = 7 - daysLeft;
            var daysInPreviousMonth = new Date(this.year, lastMonth, 0).getDate();
            first = daysInPreviousMonth - numOfDaysInWeek + 1;
            var lastDays = first + 6;
            first = { date: first, month: lastMonth };
            dateResult = { first: first, last: lastDays };
            if (lastDays > daysinMonth) {
                lastDays = lastDays - daysinMonth;
                lastDays = { date: lastDays, month: this.date.getMonth() + 2 };
                dateResult = { first: first, last: lastDays };
            }
            else {
                dateResult = { first: first, last: lastDays };
            }
        }
        else {
            var first_1 = this.day - this.date.getDay() - 7;
            last = first_1 + 6;
            var daysinMonth = new Date(this.year, this.month, 0).getDate();
            if (last > daysinMonth) {
                last = last - daysinMonth;
                last = { date: last, month: this.date.getMonth() + 2 };
                dateResult = { first: first_1, last: last };
            }
            else {
                dateResult = { first: first_1, last: last };
            }
        }
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the next thirty days date
     */
    Dates.prototype.nextThirtyDays = function () {
        var date = this.retrieveDates(30, '+');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: date.last, last: first };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the last seven days date
     */
    Dates.prototype.lastSevenDays = function () {
        var date = this.retrieveDates(7, '-');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: first, last: date.last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the last thirty days date
     */
    Dates.prototype.lastThirtyDays = function () {
        var date = this.retrieveDates(30, '-');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: first, last: date.last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the last sixty days date
     */
    Dates.prototype.lastSixtyDays = function () {
        var date = this.retrieveDates(60, '-');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: first, last: date.last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the last ninety days date
     */
    Dates.prototype.lastNinetyDays = function () {
        var date = this.retrieveDates(90, '-');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: first, last: date.last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * get the first day of the month and current day
     */
    Dates.prototype.monthToDate = function () {
        var first = 1;
        var last = this.day;
        var dateResult = { first: first, last: last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
    * get the last month first and last day
    */
    Dates.prototype.lastMonth = function () {
        var first;
        var last;
        first = 1;
        var previousMonth = this.date.getMonth();
        var year = this.date.getFullYear();
        var daysInPreviousMonth = new Date(year, this.date.getMonth(), 0).getDate();
        if (previousMonth == 12) {
            year = this.date.getFullYear() - 1;
            daysInPreviousMonth = new Date(year, this.date.getMonth(), 0).getDate();
        }
        last = daysInPreviousMonth;
        last = { date: last, month: this.date.getMonth(), year: year };
        first = { date: first, month: this.date.getMonth(), year: year };
        var dateResult = { first: first, last: last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * increment day by specific days
     */
    Dates.prototype.incrementBy = function (num) {
        if (typeof num != 'number') {
            num = parseInt(num);
        }
        var date = this.retrieveDates(num, '+');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: date.last, last: first };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    /**
     * decrement day by specific days
     */
    Dates.prototype.decrementBy = function (num) {
        if (typeof num != 'number') {
            num = parseInt(num);
        }
        var date = this.retrieveDates(num, '-');
        var first = { date: date.first, month: date.month, year: date.year };
        var dateResult = { first: first, last: date.last };
        var format = this.resultDateFormat(dateResult);
        return format;
    };
    Dates.prototype.resultDateFormat = function (dateResult) {
        var firstDay = dateResult.first;
        var month = this.date.getMonth() + 1;
        if (typeof dateResult.last !== "undefined") {
            if (typeof dateResult.last == 'object') {
                if (dateResult.last.date < 10)
                    dateResult.last.date = '0' + dateResult.last.date;
                if (dateResult.last.month < 10)
                    dateResult.last.month = '0' + dateResult.last.month;
                var lastDate = this.formatMonthAndDay(dateResult.last);
            }
            else {
                if (dateResult.last < 10)
                    dateResult.last = '0' + dateResult.last;
                if (month < 10)
                    month = '0' + month;
                this.month = month;
                month = 5 - month;
                var lastDate = this.dateFormatting(dateResult.last);
                month = this.date.getMonth() + 1;
            }
        }
        if (typeof dateResult.first == 'object') {
            if (dateResult.first.date < 10)
                dateResult.first.date = '0' + dateResult.first.date;
            if (dateResult.first.month < 10)
                dateResult.first.month = '0' + dateResult.first.month;
            var firstDate = this.formatMonthAndDay(dateResult.first);
        }
        else {
            if (firstDay < 10)
                firstDay = '0' + firstDay;
            if (month < 10)
                month = '0' + month;
            this.month = month;
            var firstDate = this.dateFormatting(firstDay);
        }
        return typeof lastDate != "undefined" ? { first: firstDate, last: lastDate } : { date: firstDate };
    };
    Dates.prototype.dateFormatting = function (date) {
        if (typeof this.dateSymbol == "undefined") {
            this.dateSymbol = { symbol: '/', position: "Day first" };
        }
        if (this.dateSymbol.position == "Day first") {
            this.formatDates = date + this.dateSymbol.symbol + this.month + this.dateSymbol.symbol + this.year;
        }
        else if (this.dateSymbol.position == "Day second") {
            this.formatDates = this.month + this.dateSymbol.symbol + date + this.dateSymbol.symbol + this.year;
        }
        else {
            this.formatDates = this.month + this.dateSymbol.symbol + date + this.dateSymbol.symbol + this.year;
        }
        return this.formatDates;
    };
    Dates.prototype.formatMonthAndDay = function (result) {
        if (typeof this.dateSymbol == "undefined") {
            this.dateSymbol = { symbol: '/', position: "Day first" };
        }
        if (this.dateSymbol.position == "Day first") {
            if (typeof result.year !== "undefined") {
                this.formatDates = result.date + this.dateSymbol.symbol + result.month + this.dateSymbol.symbol + result.year;
            }
            else {
                this.formatDates = result.date + this.dateSymbol.symbol + result.month + this.dateSymbol.symbol + this.year;
            }
        }
        else if (this.dateSymbol.position == "Day second") {
            if (typeof result.year !== "undefined") {
                this.formatDates = result.month + this.dateSymbol.symbol + result.date + this.dateSymbol.symbol + result.year;
            }
            else {
                this.formatDates = result.month + this.dateSymbol.symbol + result.date + this.dateSymbol.symbol + this.year;
            }
        }
        else {
            if (typeof result.year !== "undefined") {
                this.formatDates = result.month + this.dateSymbol.symbol + result.date + this.dateSymbol.symbol + result.year;
            }
            else {
                this.formatDates = result.month + this.dateSymbol.symbol + result.date + this.dateSymbol.symbol + this.year;
            }
        }
        return this.formatDates;
    };
    Dates.prototype.retrieveDates = function (num, operator) {
        var last = this.day;
        var date = new Date();
        if (operator == '+') {
            date.setDate(this.day + num);
        }
        else {
            date.setDate(this.day - num);
        }
        var dates = date.toISOString().substring(0, 10);
        var splitDate = dates.split('-');
        var first = splitDate[2];
        var month = splitDate[1];
        var year = splitDate[0];
        var monthSplit = month;
        var subMonth = month.substring(0, 1);
        var subDay = first.substring(0, 1);
        if (subMonth.includes('0')) {
            monthSplit = month.split('0')[1];
        }
        if (subDay.includes('0')) {
            first = first.split('0')[1];
        }
        return { first: first, last: last, month: monthSplit, year: year };
    };
    return Dates;
}());
exports.Dates = Dates;
